==> HTML-Menu-TreeView-1.07.tar.gz: HTML-Menu-TreeView-1.07/httpdocs/style/Crystal/64/html-menu-treeview/preload.js <==
var folderClosed = new Image(64,64);
folderClosed.src='/style/Crystal/64/html-menu-treeview/folder.png';
var plusNode = new Image(64,64);
plusNode.src='/style/Crystal/64/html-menu-treeview/plusNode.gif';
var lastPlusNode = new Image(64,64);
lastPlusNode.src='/style/Crystal/64/html-menu-treeview/lastPlusNode.gif';
var clasicPlusNode = new Image(64,64);
clasicPlusNode.src='/style/Crystal/64/html-menu-treeview/clasicPlusNode.gif';
var clasicLastPlusNode = new Image(64,64);
clasicLastPlusNode.src='/style/Crystal/64/html-menu-treeview/clasicLastPlusNode.gif';
var folderManClosed = new Image(64,64);
folderManClosed.src='/style/Crystal/64/html-menu-treeview/folder_man.png';
var folderGray = new Image(64,64);
folderGray.src='/style/Crystal/64/html-menu-treeview/folderGray.gif';
var folderGreen = new Image(64,64);
folderGreen.src='/style/Crystal/64/html-menu-treeview/folderGreen.gif';
var folderViolet = new Image(64,64);
folderViolet.src='/style/Crystal/64/html-menu-treeview/folderViolet.gif';
var folderYellowClosed = new Image(64,64);
folderYellowClosed.src='/style/Crystal/64/html-menu-treeview/folder_yellow.png';
var folderOrangeClosed = new Image(64,64);
folderOrangeClosed.src='/style/Crystal/64/html-menu-treeview/folder_orange.png';
var folderManClosed = new Image(64,64);
folderManClosed.src='/style/Crystal/64/html-menu-treeview/folder_man.png';
var folderHtmlClosed = new Image(64,64);
folderHtmlClosed.src='/style/Crystal/64/html-menu-treeview/folder_html.png';
var folderFavoriteClosed = new Image(64,64);
folderFavoriteClosed.src='/style/Crystal/64/html-menu-treeview/folder_favorite.png';
var folderTextClosed = new Image(64,64);
folderTextClosed.src='/style/Crystal/64/html-menu-treeview/folder_text.png';
var folderLockedClosed = new Image(64,64);
folderLockedClosed.src='/style/Crystal/64/html-menu-treeview/folder_locked.png';
var folderCrystalClosed = new Image(64,64);
folderCrystalClosed.src='/style/Crystal/64/html-menu-treeview/folder_crystal.png';
var folderVideoClosed = new Image(64,64);
folderVideoClosed.src='/style/Crystal/64/html-menu-treeview/folder_video.png';
var folderPrintClosed = new Image(64,64);
folderPrintClosed.src='/style/Crystal/64/html-menu-treeview/folder_print.png';
var folderImageClosed = new Image(64,64);
folderImageClosed.src='/style/Crystal/64/html-menu-treeview/folder_image.png';
var folderSoundClosed = new Image(64,64);
folderSoundClosed.src='/style/Crystal/64/html-menu-treeview/folder_sound.png';
var folderImportantClosed = new Image(64,64);
folderImportantClosed.src='/style/Crystal/64/html-menu-treeview/folder_important.png';
var folderTarClosed = new Image(64,64);
folderTarClosed.src='/style/Crystal/64/html-menu-treeview/folder_tar.png';

==> HTML-Menu-TreeView-1.21.tar.gz: HTML-Menu-TreeView-1.21/httpdocs/style/Crystal/64/html-menu-treeview/preload.js <==
var folderClosed = new Image(64,64);
folderClosed.src='/style/Crystal/64/html-menu-treeview/folder.png';
var plusNode = new Image(64,64);
plusNode.src='/style/Crystal/64/html-menu-treeview/plusNode.gif';
var lastPlusNode = new Image(64,64);
lastPlusNode.src='/style/Crystal/64/html-menu-treeview/lastPlusNode.gif';
var clasicPlusNode = new Image(64,64);
clasicPlusNode.src='/style/Crystal/64/html-menu-treeview/clasicPlusNode.gif';
var clasicLastPlusNode = new Image(64,64);
clasicLastPlusNode.src='/style/Crystal/64/html-menu-treeview/clasicLastPlusNode.gif';
var folderManClosed = new Image(64,64);
folderManClosed.src='/style/Crystal/64/html-menu-treeview/folder_man.png';
var folderGray = new Image(64,64);
folderGray.src='/style/Crystal/64/html-menu-treeview/folder_grey.png';
var folderGreen = new Image(64,64);
folderGreen.src='/style/Crystal/64/html-menu-treeview/folder_green.png';
var folderViolet = new Image(64,64);
folderViolet.src='/style/Crystal/64/html-menu-treeview/folder_violet.png';
var folderYellowClosed = new Image(64,64);
folderYellowClosed.src='/style/Crystal/64/html-menu-treeview/folder_yellow.png';
var folderOrangeClosed = new Image(64,64);
folderOrangeClosed.src='/style/Crystal/64/html-menu-treeview/folder_orange.png';
var folderManClosed = new Image(64,64);
folderManClosed.src='/style/Crystal/64/html-menu-treeview/folder_man.png';
var folderHtmlClosed = new Image(64,64);
folderHtmlClosed.src='/style/Crystal/64/html-menu-treeview/folder_html.png';
var folderFavoriteClosed = new Image(64,64);
folderFavoriteClosed.src='/style/Crystal/64/html-menu-treeview/folder_favorite.png';
var folderTextClosed = new Image(64,64);
folderTextClosed.src='/style/Crystal/64/html-menu-treeview/folder_txt.png';
var folderLockedClosed = new Image(64,64);
folderLockedClosed.src='/style/Crystal/64/html-menu-treeview/folder_locked.png';
var folderCrystalClosed = new Image(64,64);
folderCrystalClosed.src='/style/Crystal/64/html-menu-treeview/folder_crystal.png';
var folderVideoClosed = new Image(64,64);
folderVideoClosed.src='/style/Crystal/64/html-menu-treeview/folder_video.png';
var folderPrintClosed = new Image(64,64);
folderPrintClosed.src='/style/Crystal/64/html-menu-treeview/folder_print.png';
var folderImageClosed = new Image(64,64);
folderImageClosed.src='/style/Crystal/64/html-menu-treeview/folder_image.png';
var folderSoundClosed = new Image(64,64);
folderSoundClosed.src='/style/Crystal/64/html-menu-treeview/folder_sound.png';
var folderImportantClosed = new Image(64,64);
folderImportantClosed.src='/style/Crystal/64/html-menu-treeview/folder_important.png';
var folderTarClosed = new Image(64,64);
folderTarClosed.src='/style/Crystal/64/html-menu-treeview/folder_tar.png';
